@@ -1,7 +1,7 @@
 package App::cryp::Cmd::Exchange::open_orders;
 
-our $DATE = '2018-11-29'; # DATE
-our $VERSION = '0.011'; # VERSION
+our $DATE = '2021-05-26'; # DATE
+our $VERSION = '0.012'; # VERSION
 
 use 5.010;
 use strict;
@@ -29,7 +29,7 @@ App::cryp::Cmd::Exchange::open_orders - List open orders
 
 =head1 VERSION
 
-This document describes version 0.011 of App::cryp::Cmd::Exchange::open_orders (from Perl distribution App-cryp-exchange), released on 2018-11-29.
+This document describes version 0.012 of App::cryp::Cmd::Exchange::open_orders (from Perl distribution App-cryp-exchange), released on 2021-05-26.
 
 =head1 FUNCTIONS
 
@@ -38,7 +38,7 @@ This document describes version 0.011 of App::cryp::Cmd::Exchange::open_orders (
 
 Usage:
 
- handle_cmd(%args) -> [status, msg, payload, meta]
+ handle_cmd(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 List open orders.
 
@@ -52,16 +52,17 @@ Arguments ('*' denotes required arguments):
 
 =item * B<pair> => I<str>
 
+
 =back
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -75,7 +76,7 @@ Source repository is at L<https://github.com/perlancar/perl-App-cryp-exchange>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-cryp-exchange>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-cryp-exchange/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -87,7 +88,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
