@@ -1,7 +1,7 @@
 package App::cryp::Exchange::indodax;
 
-our $DATE = '2018-11-29'; # DATE
-our $VERSION = '0.011'; # VERSION
+our $DATE = '2021-05-26'; # DATE
+our $VERSION = '0.012'; # VERSION
 
 use 5.010001;
 use strict;
@@ -559,7 +559,7 @@ App::cryp::Exchange::indodax - Interact with Indodax
 
 =head1 VERSION
 
-This document describes version 0.011 of App::cryp::Exchange::indodax (from Perl distribution App-cryp-exchange), released on 2018-11-29.
+This document describes version 0.012 of App::cryp::Exchange::indodax (from Perl distribution App-cryp-exchange), released on 2021-05-26.
 
 =for Pod::Coverage ^(.+)$
 
@@ -583,7 +583,7 @@ Source repository is at L<https://github.com/perlancar/perl-App-cryp-exchange>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-cryp-exchange>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-cryp-exchange/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -595,7 +595,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
